library("tidyverse")
library("reshape2")

df <- read.csv("4.lipid_enrichment.csv",header=T)

res <- df %>% group_by(Label) %>% summarize(chol=mean(feCHOL)) %>% as.data.frame()
res$Label <- tolower(res$Label)


dlpe <- df %>% group_by(Label) %>% summarize(lip=mean(feDLPE)) %>% select(lip) %>% as.data.frame()
papc <- df %>% group_by(Label) %>% summarize(lip=mean(fePAPC)) %>% select(lip) %>% as.data.frame()
popc <- df %>% group_by(Label) %>% summarize(lip=mean(fePOPC)) %>% select(lip) %>% as.data.frame()
pope <- df %>% group_by(Label) %>% summarize(lip=mean(fePOPE)) %>% select(lip) %>% as.data.frame()
ssm <- df %>% group_by(Label) %>% summarize(lip=mean(feSSM)) %>% select(lip) %>% as.data.frame()

res$dlpe <- dlpe$lip
res$papc <- papc$lip
res$popc <- popc$lip
res$pope <- pope$lip
res$ssm <- ssm$lip

dfcombined <- melt(data=res,id.vars="Label",variable.name="Y",value.name="Z", 
measure.vars=c("chol","dlpe","papc","popc","pope","ssm"))

colnames(dfcombined) <- c("X","Y","Z")
dfcombined$X <- toupper(dfcombined$X)
dfcombined$Y <- toupper(dfcombined$Y)
dfcombined$Z <- signif(dfcombined$Z,2)

rng <- range(c(min(dfcombined$Z),max(dfcombined$Z))) 

###
my_theme <- function(base_size=28,base_family="Arial",colr="black") {
  theme_bw(base_size=base_size, base_family=base_family) %+replace%
    theme(
      strip.background=element_blank(),
      strip.text.x=element_text(size=base_size),
      strip.text.y=element_text(size=base_size),
      axis.text.x=element_text(size=base_size,color=colr),
      axis.text.y=element_text(size=base_size,color=colr),
      axis.line.x=element_line(linewidth=0.25,color=colr),
      axis.line.y=element_line(linewidth=0.25,color=colr), 
      axis.title.x=element_text(size=base_size,color=colr),
      axis.title.y=element_text(size=base_size,color=colr, angle=90), 
      axis.ticks=element_line(color=colr),
      panel.background=element_blank(),
      panel.grid.major=element_blank(),
      panel.grid.minor=element_blank(),
      #panel.border=element_rect(colour="white"),
      plot.background=element_blank(),
      plot.margin=unit(c(0.5,1.0,0.5,0.5),"lines"),
      legend.title=element_blank(),panel.spacing = unit(2, "lines")
      )
}
###


scaleFUN <- function(x) sprintf("%.2f", x)

p <- ggplot(dfcombined,aes(x=as.factor(X),y=as.factor(Y),fill=Z))+geom_tile()+
  scale_fill_gradient2(low="red", mid="white", high="blue", #colors in the scale
                 midpoint=1,    #same midpoint for plots (mean of the range)
		 breaks=c(0,1,2),labels=c(0,1,2),
                 limits=c(0,2)
  ) +  #same limits for plot
  my_theme()+ 
  xlab(NULL) + ylab(NULL)+
  geom_text(aes(label = scaleFUN(Z)), color = "black", fontface = "bold", size = 12)  

png(file="4.lipid_enrichment.png", width=14,
     height=10, unit="in", res=400) 
print(p)
dev.off()

