##################libraries
library("dplyr")
library("ggplot2")
library("reshape2")
library("zoo")
library("Peptides")
##################

theme_mine <- function(base_size = 24, base_family = "Helvetica") {
  # Starts with theme_grey and then modify some parts
  theme_bw(base_size = base_size, base_family = base_family) %+replace%
    theme(
      strip.background = element_blank(),
      strip.text.x = element_text(size = base_size),
      strip.text.y = element_text(size = base_size),
      axis.text.x = element_text(size = base_size, colour="black"),
      axis.text.y = element_text(size = base_size, colour="black"),
      axis.ticks =  element_line(colour = "black"), 
      axis.title.x = element_text(size = base_size, colour="black"),
      axis.title.y = element_text(size = base_size, colour="black", angle=90),
      legend.text = element_text(size = base_size),
      panel.background = element_blank(), 
      panel.grid.major = element_blank(), 
      panel.grid.minor = element_blank(), 
      #panel.border = element_rect(colour="black"), 
      plot.background = element_blank(), 
      plot.margin = unit(c(0.5,  0.5, 0.5, 0.5), "lines"),
      axis.line.x = element_line(colour="black", linewidth = 0.25),
      axis.line.y = element_line(colour="black", linewidth = 0.25)
    )
}

################### READ DATA##

#asssumes 1 frame per ns was saved to calculate simulation time
df <- readXVG("2.z_densities.xvg")

##assumes that indices were group with the following order:
colnames(df) <- c("z","water", "headgroups", "roh", "esters", "tails", "sodium", "chloride")
df$water <- as.numeric(df$water)
df$headgroups <- as.numeric(df$headgroups)
df$roh <- as.numeric(df$roh)
df$esters <- as.numeric(df$esters)
df$tails <- as.numeric(df$tails)
df$sodium <- as.numeric(df$sodium)
df$chloride <- as.numeric(df$chloride)


all <- melt(df,id="z")
colnames(all) <- c("z","leg","dens")
all$dens <- as.numeric(all$dens)
all$z <- as.numeric(all$z)
all$leg <- factor(all$leg, levels=c("water","headgroups","roh","esters","tails","sodium","chloride"))
colors <- c("#0072B2","purple","black","#E69F00","#999999","#F0E442","#009E73")
all$ng <- case_when(all$leg %in% c("roh","sodium","chloride") ~ 1, all$leg %in% c("headgroups","esters","tails","water") ~ 2)


################# PLOT #####

plotyy <-ggplot(all, aes(x=z,y=dens,group=leg, col=leg)) + 
	geom_line(lwd=1.1) +
#  	facet_grid(cols=vars(sys), scales="free_x")+
 	theme_mine() + 
	theme(legend.title = element_blank(),
        	#legend.position="none") +
		panel.spacing = unit(2, "lines"))+
		theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 0)),
		axis.title.x = element_text(margin = margin(t = 10, r = 00, b = 0, l = 0)))+ #increse separation btw legend and axis
	ylab(expression("Number density (nm"^-2~")")) + 
	xlab(expression("Z coordinate (nm)"))+
	scale_color_manual(values=colors)
 
png(file="2.z_densities_figure.png", width=24,
    height=12, unit="cm", res=800)
print(plotyy)
dev.off()

png(file="2.z_densities_plot.png", width=36,
    height=12, unit="cm", res=800)
print(plotyy+facet_wrap( ~ ng, scales="free") +  theme(strip.background = element_blank(), strip.text.x = element_blank()))
dev.off()
