#!/usr/bin/env python

import MDAnalysis as mda
from lipyphilic.lib.assign_leaflets import AssignLeaflets
from lipyphilic.lib.neighbours import Neighbours
import pandas as pd
import numpy as np


u = mda.Universe('membrane.gro','whole.xtc')


leaflets = AssignLeaflets(
  universe=u,
  lipid_sel="name PO4 ROH",
  midplane_sel="resname CHOL and name ROH",
  midplane_cutoff=10.0
)

leaflets.run(start=None, stop=None, step=None)  

neighbours = Neighbours(universe=u, lipid_sel="name GL1 GL2 OH1 AM2 ROH", cutoff=15)
neighbours.run(start=None,stop=None,step=None,verbose=True)

counts, enrichment = neighbours.count_neighbours(return_enrichment=True)

counts.to_csv("4.lipid_counts.csv", index=0)
enrichment.to_csv("4.lipid_enrichment.csv", index=0)
