
###to use: python 3.membrane_thickness.py -str ../lipids-water.gro -trj whole.xtc -sel PO4 

import sys, os, argparse
import MDAnalysis as mda
from lipyphilic.lib.assign_leaflets import AssignLeaflets
from lipyphilic.lib.memb_thickness import MembThickness
import pandas as pd
import numpy as np


def thickness_calc(GRO,TRJ,SEL):


  import warnings
  # suppress some MDAnalysis warnings about PSF files
  warnings.filterwarnings('ignore')

  u = mda.Universe(GRO,TRJ)
  leaflets = AssignLeaflets(universe=u, lipid_sel="name "+str(SEL))
  leaflets.run(start=None, stop=None, step=None)  

  memb_thickness = MembThickness(u,leaflets=leaflets.filter_leaflets("name "+str(SEL)), lipid_sel="name "+str(SEL))
  memb_thickness.run()

  thickness = memb_thickness.memb_thickness.mean()/10 #convert to nm
  thickness_std = memb_thickness.memb_thickness.std()/10 # convert to nm

  print("Membrane thickness:  %.2f +/- %.2f nm (MEAN +/- STD)" % (thickness,thickness_std))


if __name__ == "__main__":
  if len(sys.argv)<3:
    raise SystemExit("Reads in .gro and .xtc files and calculates membrane thickness")
  parser = argparse.ArgumentParser()
  parser.add_argument('-str', '--structure_file', nargs='?')
  parser.add_argument('-trj', '--trajectory', nargs='?')
  parser.add_argument('-sel', '--atom_selection', nargs='?') 
          
  parsed = parser.parse_args()
  GRO = parsed.__dict__['structure_file']
  TRJ = parsed.__dict__['trajectory']
  SEL = parsed.__dict__['atom_selection']

  thickness_calc(GRO,TRJ,SEL)
