#!/usr/bin/env python

import MDAnalysis as mda
from lipyphilic.lib.assign_leaflets import AssignLeaflets
from lipyphilic.lib.neighbours import Neighbours
import pandas as pd
import numpy as np


u = mda.Universe('../2.simulate/lipids-water-em.gro','whole.xtc')

leaflets = AssignLeaflets(
  universe=u,
  lipid_sel="name PO4 ROH",
  midplane_sel="resname CHOL and name ROH",
  midplane_cutoff=10.0
)

leaflets.run(start=None, stop=None, step=None)  

def conditions(x):
  if x == "CHOL": return 1
  elif x == "DLPE": return 2
  elif x == "PAPC": return 3
  elif x == "PAPS": return 4
  elif x == "POPX": return 5
  elif x == "POPE": return 6
  elif x == "POPC": return 5
  elif x == "SAP6": return 7
  elif x == "SSM": return 8

func=np.vectorize(conditions)
mylabels=func(leaflets.membrane.resnames)
mylist=np.copy(leaflets.leaflets)

for i in range(np.shape(leaflets.leaflets)[1]):
  mylist[:,i]=mylist[:,i]*mylabels

#change the lipidlabels if using different lipid species:
lipidlabels = {'OUTER-CHOL':1,'OUTER-DLPE':2,'OUTER-PAPC':3,'OUTER-POPC':5,'OUTER-POPE':6,'OUTER-SSM':8,'INNER-CHOL':-1,'INNER-DLPE':-2,'INNER-PAPC':-3,'INNER-PAPS':-4,'INNER-POPC':-5,'INNER-POPE':-6,'INNER-SAP6':-7,'INNER-SSM':-8,'MID-ANY':0}


neighbours = Neighbours(universe=u, lipid_sel="name GL1 GL2 OH1 AM2 ROH", cutoff=15)
neighbours.run(start=None,stop=None,step=None,verbose=True)

counts, enrichment = neighbours.count_neighbours(
  count_by=mylist,
  count_by_labels=lipidlabels,
  return_enrichment=True
)

counts.to_csv("4.lipid_counts.csv", index=0)

