library("tidyverse")
library("reshape2")

df <- read.csv("4.lipid_counts.csv",header=T)

inner <- df %>% filter(grepl("^INNER",Label)) %>% 
  select(Label | Resindex | Frame | starts_with("nINNER")) %>%
  as.data.frame()
outer <- df %>% filter(grepl("^OUTER",Label)) %>% 
  select(Label | Resindex | Frame | starts_with("nOUTER")) %>% 
  as.data.frame()

#assume that in the inner and outer data frames, the first
#three columns are Label,Resindex and Frame

inner_mean <- inner %>% group_by(Label) %>% summarise(across(colnames(inner)[4:ncol(inner)], mean))
colnames(inner_mean) <- gsub("nINNER.","",colnames(inner_mean))
inner_mean$Label <- gsub("INNER-","",inner_mean$Label)
inner_normalize <- as.data.frame(colMeans(inner_mean[2:ncol(inner_mean)])) #assumes inner_mean has only first col as non-numeric

#this part normalizes the lipid neighbour count
inner_mean$CHOL <- inner_mean$CHOL/inner_normalize['CHOL',1]
inner_mean$DLPE <- inner_mean$DLPE/inner_normalize['DLPE',1]
inner_mean$PAPC <- inner_mean$PAPC/inner_normalize['PAPC',1]
inner_mean$PAPS <- inner_mean$PAPS/inner_normalize['PAPS',1]
inner_mean$POPC <- inner_mean$POPC/inner_normalize['POPC',1]
inner_mean$POPE <- inner_mean$POPE/inner_normalize['POPE',1]
inner_mean$SAP6 <- inner_mean$SAP6/inner_normalize['SAP6',1]
inner_mean$SSM <- inner_mean$SSM/inner_normalize['SSM',1]

outer_mean <- outer %>% group_by(Label) %>% summarise(across(colnames(outer)[4:ncol(outer)], mean))
colnames(outer_mean) <- gsub("nOUTER.","",colnames(outer_mean))
outer_mean$Label <- gsub("OUTER-","",outer_mean$Label)
outer_normalize <- as.data.frame(colMeans(outer_mean[2:ncol(outer_mean)])) #assumes inner_mean has only first col as non-numeric

outer_mean$CHOL <- outer_mean$CHOL/outer_normalize['CHOL',1]  
outer_mean$DLPE <- outer_mean$DLPE/outer_normalize['DLPE',1]
outer_mean$PAPC <- outer_mean$PAPC/outer_normalize['PAPC',1]
outer_mean$SSM <- outer_mean$SSM/outer_normalize['SSM',1]  
outer_mean$POPC <- outer_mean$POPC/outer_normalize['POPC',1]
outer_mean$POPE <- outer_mean$POPE/outer_normalize['POPE',1]


outer_enrichment <- melt(data=outer_mean,id.vars="Label",variable.name="Y",value.name="Z")
colnames(outer_enrichment) <- c("X","Y","Z")
outer_enrichment$Z <- signif(outer_enrichment$Z,3)

inner_enrichment <- melt(data=inner_mean,id.vars="Label",variable.name="Y",value.name="Z")
colnames(inner_enrichment) <- c("X","Y","Z")
inner_enrichment$Z <- signif(inner_enrichment$Z,3)


rng <- c(0.5,0.8,0.92,1.0,1.08,1.2,1.5)

###
my_theme <- function(base_size=28,base_family="Arial",colr="black") {
  theme_bw(base_size=base_size, base_family=base_family) %+replace%
    theme(
      strip.background=element_blank(),
      strip.text.x=element_text(size=base_size),
      strip.text.y=element_text(size=base_size),
      axis.text.x=element_text(size=base_size,color=colr),
      axis.text.y=element_text(size=base_size,color=colr),
      axis.line.x=element_line(linewidth=0.25,color=colr),
      axis.line.y=element_line(linewidth=0.25,color=colr), 
      axis.title.x=element_text(size=base_size,color=colr),
      axis.title.y=element_text(size=base_size,color=colr, angle=90), 
      axis.ticks=element_line(color=colr),
      panel.background=element_blank(),
      panel.grid.major=element_blank(),
      panel.grid.minor=element_blank(),
      #panel.border=element_rect(colour="white"),
      plot.background=element_blank(),
      plot.margin=unit(c(0.5,1.0,0.5,0.5),"lines"),
      legend.title=element_blank(),panel.spacing = unit(2, "lines")
      )
}
###


scaleFUN <- function(x) sprintf("%.2f", x)

outer_enrichment$X <- factor(outer_enrichment$X, levels=c("CHOL","DLPE","PAPC","POPC","POPE","SSM"))
outer_enrichment$Y <- factor(outer_enrichment$Y, levels=c("CHOL","DLPE","PAPC","POPC","POPE","SSM"))
 

p <- ggplot(outer_enrichment,aes(x=as.factor(X),y=as.factor(Y),fill=Z))+geom_tile()+
  scale_fill_gradient2(low="red", mid="white", high="blue", #colors in the scale
                 midpoint=1,    #same midpoint for plots (mean of the range)
                 breaks=c(0,1,2), #breaks in the scale bar
                 limits=c(0,2)
  ) +  #same limits for plot
  my_theme()+ 
  xlab(NULL) + ylab(NULL)+
  geom_text(aes(label = scaleFUN(Z)), color = "black", fontface = "bold", size = 12)  

png(file="4.outer_leaflet_enrichment.png", width=14,
     height=10, unit="in", res=400) 
print(p)
dev.off()


inner_enrichment$X <- factor(inner_enrichment$X, levels=c("CHOL","DLPE","PAPC","PAPS","POPC","POPE","SAP6","SSM"))
inner_enrichment$Y <- factor(inner_enrichment$Y, levels=c("CHOL","DLPE","PAPC","PAPS","POPC","POPE","SAP6","SSM"))
 

p <- ggplot(inner_enrichment,aes(x=as.factor(X),y=as.factor(Y),fill=Z))+geom_tile()+
  scale_fill_gradient2(low="red", mid="white", high="blue", #colors in the scale
                 midpoint=1,    #same midpoint for plots (mean of the range)
                 breaks=c(0,1,2), #breaks in the scale bar
                 limits=c(0,2)
  ) +  #same limits for plot
  my_theme()+
  xlab(NULL) + ylab(NULL)+
  geom_text(aes(label = scaleFUN(Z)), color = "black", fontface = "bold", size = 12)
      
png(file="4.inner_leaflet_enrichment.png", width=14,
     height=10, unit="in", res=400)
print(p)
dev.off()
